Generate Citation for Stock Assessment Report
Usage
create_citation(
authors = NULL,
title = "[TITLE]",
year = format(as.POSIXct(Sys.Date(), format = "%YYYY-%mm-%dd"), "%Y")
)Arguments
A character vector of author names and affiliations. For example, a Jane Doe at the NWFSC Seattle, Washington office would have an entry of c("Jane Doe"="NWFSC-SWA"). Information on NOAA offices can be found with:
asar::affiliation_info. Keys to the office addresses follow the naming convention of: office acronym (ex. NWFSC), a hyphen (-), the first initial of the city, and then the two-letter abbreviation for the state the office is located in. If the city has two or more words (e.g., Panama City), the first initial of each word is used in the key (ex. Panama City, Florida = PCFL).Default: NULL
Options: See
asar::affiliation_info.- title
Custom report title superceding the default composed in
asar::create_title(). Example: "Management Track Assessments Spring 2024".Default:
[TITLE]. If species and region are provided, a title will be generated based on the report type, species, and region.- year
Year the assessment is conducted.
Default: the year in which the report is rendered.
Value
Generate a citation for use in publications and other
references associated with the stock assessment report produced
with asar.
Examples
if (FALSE) { # \dontrun{
create_citation(
title = "SA Report for Jellyfish",
authors = c("Danny Phantom" = "SWFSC-LJCA", "John Snow" = "AFSC-ABL", "Jane Doe" = "NWFSC-SWA"),
year = 2024
)
} # }